// Real-time updates functionality
const updateRoutes = async () => {
  try {
    const response = await fetch('/api/routes');
    const data = await response.json();
    const routeGrid = document.querySelector('.route-grid');
    
    // Clear existing content
    routeGrid.innerHTML = '';
    
    // Add new routes
    data.forEach(route => {
      const routeCard = document.createElement('div');
      routeCard.className = 'route-card';
      routeCard.innerHTML = `
        <div class="route-icon">${route.icon}</div>
        <h3>${route.title}</h3>
        <p>${route.description}</p>
        <a href="${route.link}" class="secondary-button">View Route</a>
      `;
      routeGrid.appendChild(routeCard);
    });
  } catch (error) {
    console.error('Error updating routes:', error);
  }
};

// Flight deals functionality
const updateFlights = async () => {
  try {
    const response = await fetch('/api/flights');
    const data = await response.json();
    const flightGrid = document.querySelector('.flight-grid');
    
    // Clear existing content
    flightGrid.innerHTML = '';
    
    // Add new flights
    data.forEach(flight => {
      const flightCard = document.createElement('div');
      flightCard.className = 'flight-card';
      flightCard.innerHTML = `
        <div class="flight-icon">✈️</div>
        <h3>${flight.route}</h3>
        <p>${flight.price}</p>
        <a href="${flight.link}" class="secondary-button">Book Now</a>
      `;
      flightGrid.appendChild(flightCard);
    });
  } catch (error) {
    console.error('Error updating flights:', error);
  }
};

// Initialize updates
document.addEventListener('DOMContentLoaded', () => {
  updateRoutes();
  updateFlights();
  
  // Update every 5 minutes
  setInterval(() => {
    updateRoutes();
    updateFlights();
  }, 300000);
});